@@ -846,13 +846,13 @@ def pulsed_fraction_area(c, dc, background=None, background_error=None):
         dc (numpy array): the pulse profile uncertainty [used for error computation]
 
     Returns:
-       numpy float: the pulsed fraction
+       numpy float: the pulsed fraction!
     """
     logger.debug('remember PF is a factor  of about 1.4 the other PFs')
     a0 = 0
     if background is not None and background_error is not None:
         a0 = subtract_background(a0, background,background_error)
-    return np.sum(c-np.min(c)+a0)/np.sum(c+a0)
+    return np.sum((c - a0 ) - (np.min(c - a0) ) ) / np.sum( c-a0 )
 
 def pulse_fraction_from_data_rms(counts, counts_err, n_harm=-1, background=None, background_error=None, plot=False, label='', verbose=False):
     
@@ -975,6 +975,7 @@ def subtract_background(a0, background, background_error):
         logger.debug('Background level %f' % background_level)
         a0_out = a0 - background_level
         if a0 == 0:
+            a0_out = background_level
             logger.warning('continuum level is zero')
             #raise Exception
     return a0_out
